# ROODKCAB

## CHANGELOG

Oky i am way to lazy to write anithyng here during testing so if i got to actual pypi the i will.

1. Updated test.ps1 to include while true >> To keep the programm running. **26.06.2023 18:21:00**

2. Rewritten Every code for pip package => **I DIDIN'T delete the code ...**

3. Removed threading module from dependencies 

3. Fixed Enviroment Variable Error

## USAGE

1. May be coming soon...